from onvo.resource import Resource


class EmbedUsers(Resource):
    def list(self):
        return self.base_get("/embed-users")

    def get(self, id):
        return self.base_get(f"/embed-users/{id}")

    def delete(self, id):
        return self.base_delete(f"/embed-users/{id}")

    def upsert(self, data):
        return self.base_post("/embed-users", data)

    def get_access_token(self, id):
        return self.base_get(f"/embed-users/#{id}/token")



import unittest
from onvo import Onvo


class TestAccounts(unittest.TestCase):

    def assertShouldRaise(self, expected_exception, callable):
        if expected_exception is None:
            try:
                callable()
            except Exception as error:
                self.fail(f"Error should not have occurred: {error}")
        else:
            self.assertRaises(expected_exception, callable)

    def setup(self):
        self.onvoSDK = Onvo()

    def test_get(self):
        self.assertShouldRaise(None, self.onvoSDK.accounts.get)



import os
from onvo.accounts import Accounts

try:
    default_endpoint = os.environ["ONVO_API_ENDPOINT"]
    default_api_key = os.environ["ONVO_API_KEY"]
except:
    default_endpoint = None
    default_api_key = None


class Onvo:
    def __init__(self, endpoint=default_endpoint, api_key=default_api_key):
        self.endpoint = endpoint
        self.api_key = api_key
        self.check_init_params()

        params = [endpoint, api_key]

        self.accounts = Accounts(*params)
        # self.teams = Teams.new(*params)
        # self.embed_users = EmbedUsers.new(*params)
        # self.datasources = Datasources.new(*params)
        # self.automations = Automations.new(*params)
        # self.dashboards = Dashboards.new(*params)

    def check_init_params(self):
        if self.endpoint is None:
            raise Exception(
                "Onvo object has no endpoint! Initalize with the endpoint parameter or use ONVO_API_ENDPOINT"
            )
        if self.api_key is None:
            raise Exception(
                "Onvo object has no api key! Initalize with the api_key parameter or use ONVO_API_KEY"
            )



import requests


class Resource:
    def __init__(self, endpoint, api_key):
        self.endpoint = endpoint
        self.headers = {"x-api-key": api_key, "Content-Type": "application/json"}

    def handle_response(self, response):
        response.raise_for_status()
        try:
            return response.json()
        except ValueError:
            return response.text()

    # TODO : Add documentation marking 'params' as the query
    def base_request(self, handler, subdirectory, additional_options):
        url = f"{self.endpoint}{subdirectory}"
        options = {"headers": self.headers, **additional_options}
        response = handler(url, **options)
        return self.handle_response(response)

    def base_get(self, subdirectory, **options):
        return self.base_request(requests.get, subdirectory, options)

    def base_put(self, subdirectory, **options):
        return self.base_request(requests.put, subdirectory, options)

    def base_post(self, subdirectory, **options):
        return self.base_request(requests.post, subdirectory, options)

    def base_delete(self, subdirectory, **options):
        return self.base_request(requests.delete, subdirectory, options)
